@@ -69,7 +69,7 @@ void PseudoDTD::analyzeDTD( TQString &metaDtdUrl, TQString &metaDtd )
   listLength += doc.elementsByTagName( "attlist" ).count() * 2;
 
   TQProgressDialog progress( i18n("Analyzing meta DTD..."), i18n("Cancel"), listLength,
-                            0, "progress", TRUE );
+                            0, "progress", true );
   progress.setMinimumDuration( 400 );
   progress.setProgress(0);
 
