@@ -57,7 +57,7 @@ const int NO_BUTTONS = 4;
 
 extern "C"
 {
-	KDE_EXPORT KPanelApplet *init( TQWidget *parent, const TQString &configFile)
+	TDE_EXPORT KPanelApplet *init( TQWidget *parent, const TQString &configFile)
 	{
 		TDEGlobal::locale()->insertCatalogue("mediacontrol");
 		return new MediaControl(configFile, KPanelApplet::Normal,
@@ -139,7 +139,7 @@ MediaControl::MediaControl(const TQString &configFile, Type t, int actions,
 	playpause_button  = new TrayButton (this, "PLAYPAUSE");
 	stop_button  = new TrayButton (this, "STOP");
 	next_button  = new TrayButton (this, "NEXT");
-	time_slider  = new MCSlider (Qt::Horizontal, this, "time_slider" );
+	time_slider  = new MCSlider (TQt::Horizontal, this, "time_slider" );
 	time_slider->setRange(0,0);
 	time_slider->setValue(0);
 	time_slider->setTracking( false );
@@ -147,15 +147,15 @@ MediaControl::MediaControl(const TQString &configFile, Type t, int actions,
 
 	// request notification of changes in icon style
 	kapp->addKipcEventMask(KIPC::IconChanged);
-	connect(kapp, TQT_SIGNAL(iconChanged(int)), this, TQT_SLOT(slotIconChanged()));
+	connect(kapp, TQ_SIGNAL(iconChanged(int)), this, TQ_SLOT(slotIconChanged()));
 
 	reparseConfig();
 
 	rmbMenu = new TDEPopupMenu(this, "RMBMenu");
 	rmbMenu->insertTitle(i18n("MediaControl"), 0, 0);
 	rmbMenu->insertItem(SmallIcon("configure"), i18n("Configure MediaControl..."),
-		this, TQT_SLOT(preferences()));
-	rmbMenu->insertItem(i18n("About MediaControl"), this, TQT_SLOT(about()));
+		this, TQ_SLOT(preferences()));
+	rmbMenu->insertItem(i18n("About MediaControl"), this, TQ_SLOT(about()));
 }
 
 MediaControl::~MediaControl()
@@ -184,7 +184,7 @@ void MediaControl::dropEvent(TQDropEvent* event)
 void MediaControl::setSliderPosition(int len ,int time)
 {
 	time_slider->blockSignals(true);
-	if(orientation() ==Qt::Vertical)
+	if(orientation() ==TQt::Vertical)
 	  time = len - time;
 
 	if (mLastLen != len)
@@ -275,12 +275,12 @@ void MediaControl::preferences()
 	else
 	{
 		_prefsDialog = new MediaControlConfig ( _configFrontend );
-		connect ( _prefsDialog, TQT_SIGNAL(closing()),
-			this, TQT_SLOT(slotClosePrefsDialog()) );
-		connect ( _prefsDialog, TQT_SIGNAL(destroyed()),
-			this, TQT_SLOT(slotPrefsDialogClosing()) );
-		connect ( _prefsDialog, TQT_SIGNAL(configChanged()),
-			this, TQT_SLOT(slotConfigChanged()) );
+		connect ( _prefsDialog, TQ_SIGNAL(closing()),
+			this, TQ_SLOT(slotClosePrefsDialog()) );
+		connect ( _prefsDialog, TQ_SIGNAL(destroyed()),
+			this, TQ_SLOT(slotPrefsDialogClosing()) );
+		connect ( _prefsDialog, TQ_SIGNAL(configChanged()),
+			this, TQ_SLOT(slotConfigChanged()) );
 	}
 }
 
@@ -318,7 +318,7 @@ void MediaControl::reportBug()
 // Fixing the orientation problem in qslider.
 void MediaControl::adjustTime(int time)
 {
-	if(orientation() ==Qt::Vertical)
+	if(orientation() ==TQt::Vertical)
 		emit(newJumpToTime(mLastLen - time));
 	else
 		emit(newJumpToTime(time));
@@ -396,12 +396,12 @@ void MediaControl::reparseConfig()
 	}
 
 	//  this signal gets emitted by a playerInterface when the player's playtime changed
-	connect(_player, TQT_SIGNAL(newSliderPosition(int,int)),
-		this, TQT_SLOT(setSliderPosition(int,int)));
+	connect(_player, TQ_SIGNAL(newSliderPosition(int,int)),
+		this, TQ_SLOT(setSliderPosition(int,int)));
 
-	connect(_player, TQT_SIGNAL(playerStarted()), TQT_SLOT(enableAll()));
-	connect(_player, TQT_SIGNAL(playerStopped()), TQT_SLOT(disableAll()));
-	connect(_player, TQT_SIGNAL(playingStatusChanged(int)), TQT_SLOT(slotPlayingStatusChanged(int)));
+	connect(_player, TQ_SIGNAL(playerStarted()), TQ_SLOT(enableAll()));
+	connect(_player, TQ_SIGNAL(playerStopped()), TQ_SLOT(disableAll()));
+	connect(_player, TQ_SIGNAL(playingStatusChanged(int)), TQ_SLOT(slotPlayingStatusChanged(int)));
 
 	// do we use our icons or the default ones from KDE?
 	if(_configFrontend->useCustomTheme())
@@ -441,17 +441,17 @@ void MediaControl::reparseConfig()
 
 	slider_tooltip = new MediaControlToolTip(time_slider, _player);
 
-	connect(prev_button, TQT_SIGNAL(clicked()), _player, TQT_SLOT(prev()));
-	connect(playpause_button, TQT_SIGNAL(clicked()), _player, TQT_SLOT(playpause()));
-	connect(stop_button, TQT_SIGNAL(clicked()), _player, TQT_SLOT(stop()));
-	connect(next_button, TQT_SIGNAL(clicked()), _player, TQT_SLOT(next()));
+	connect(prev_button, TQ_SIGNAL(clicked()), _player, TQ_SLOT(prev()));
+	connect(playpause_button, TQ_SIGNAL(clicked()), _player, TQ_SLOT(playpause()));
+	connect(stop_button, TQ_SIGNAL(clicked()), _player, TQ_SLOT(stop()));
+	connect(next_button, TQ_SIGNAL(clicked()), _player, TQ_SLOT(next()));
 
-	connect(time_slider, TQT_SIGNAL(sliderPressed()), _player, TQT_SLOT(sliderStartDrag()));
-	connect(time_slider, TQT_SIGNAL(sliderReleased()), _player, TQT_SLOT(sliderStopDrag()));
-	connect(time_slider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(adjustTime(int)));
-	connect(time_slider, TQT_SIGNAL(volumeUp()), _player, TQT_SLOT(volumeUp()));
-	connect(time_slider, TQT_SIGNAL(volumeDown()), _player, TQT_SLOT(volumeDown()));
-	connect(this, TQT_SIGNAL(newJumpToTime(int)), _player, TQT_SLOT(jumpToTime(int)));
+	connect(time_slider, TQ_SIGNAL(sliderPressed()), _player, TQ_SLOT(sliderStartDrag()));
+	connect(time_slider, TQ_SIGNAL(sliderReleased()), _player, TQ_SLOT(sliderStopDrag()));
+	connect(time_slider, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(adjustTime(int)));
+	connect(time_slider, TQ_SIGNAL(volumeUp()), _player, TQ_SLOT(volumeUp()));
+	connect(time_slider, TQ_SIGNAL(volumeDown()), _player, TQ_SLOT(volumeDown()));
+	connect(this, TQ_SIGNAL(newJumpToTime(int)), _player, TQ_SLOT(jumpToTime(int)));
 }
 
 // Widget Placement ===================================================================
@@ -498,7 +498,7 @@ int MediaControl::heightForWidth(int width) const
 
 void MediaControl::mousePressEvent(TQMouseEvent* e)
 {
-	if (e->button() == Qt::RightButton)
+	if (e->button() == TQt::RightButton)
 		rmbMenu->popup(e->globalPos());
 }
 
@@ -506,8 +506,8 @@ bool MediaControl::eventFilter(TQObject *, TQEvent *e)
 {
 	if (e->type() == TQEvent::MouseButtonPress)
 	{
-		TQMouseEvent *me = TQT_TQMOUSEEVENT(e);
-		if (me->button() == Qt::RightButton)
+		TQMouseEvent *me = static_cast<TQMouseEvent*>(e);
+		if (me->button() == TQt::RightButton)
 		{
 			rmbMenu->popup(me->globalPos());
 			return true;
@@ -532,9 +532,9 @@ void MediaControl::resizeEvent( TQResizeEvent* )
 //	kdDebug(90200) << "resizeEvent()" << endl;
 	int w = width();
 	int h = height();
-	if ( orientation() ==Qt::Vertical )
+	if ( orientation() ==TQt::Vertical )
 	{		// ====== VERTICAL =================================================
-		time_slider->setOrientation(Qt::Vertical);
+		time_slider->setOrientation(TQt::Vertical);
 		int slider_width = time_slider->minimumSizeHint().width();
 		// some styles need more space for sliders than avilable in very small panels :(
 		if ( slider_width > w ) slider_width = w;
@@ -566,7 +566,7 @@ void MediaControl::resizeEvent( TQResizeEvent* )
 	}
 	else	// ====== HORIZONTAL ===============================================
 	{
-		time_slider->setOrientation(Qt::Horizontal);
+		time_slider->setOrientation(TQt::Horizontal);
 		int slider_height = time_slider->minimumSizeHint().height();
 		// some styles need more space for sliders than avilable in very small panels :(
 		if ( slider_height > h ) slider_height = h;
