@@ -100,13 +100,13 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const TQStringLis
             item = itemList.first();
             m_name = itemList.first()->name();
             action = new TDEAction( i18n( "Compress as %1" ).arg( m_name + m_ext ), 0, this,
-                                    TQT_SLOT( slotCompressAsDefault() ), actionCollection() );
+                                    TQ_SLOT( slotCompressAsDefault() ), actionCollection() );
         }
         else
         {
             action = new TDEAction( KMimeType::mimeType( m_conf->readEntry(
                                     "LastMimeType", "application/x-txz" ) )->comment(),
-                                    0, this, TQT_SLOT( slotCompressAsDefault() ), actionCollection() );
+                                    0, this, TQ_SLOT( slotCompressAsDefault() ), actionCollection() );
         }
         actionMenu->insert( action );
 
@@ -118,14 +118,14 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const TQStringLis
         if ( itemList.first()->url().isLocalFile() )
             actionMenu->insert( m_addToMenu );
 
-        connect( m_compAsMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ),
-                this, TQT_SLOT( slotPrepareCompAsMenu() ) );
-        connect( m_addToMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ),
-                this, TQT_SLOT( slotPrepareAddToMenu() ) );
+        connect( m_compAsMenu->popupMenu(), TQ_SIGNAL( aboutToShow() ),
+                this, TQ_SLOT( slotPrepareCompAsMenu() ) );
+        connect( m_addToMenu->popupMenu(), TQ_SIGNAL( aboutToShow() ),
+                this, TQ_SLOT( slotPrepareAddToMenu() ) );
 
 
         action = new TDEAction( i18n( "Add to Archive..." ), 0, this,
-                                TQT_SLOT( slotAdd() ), actionCollection() );
+                                TQ_SLOT( slotAdd() ), actionCollection() );
         actionMenu->insert( action );
         addAction( actionMenu );
     }
@@ -137,7 +137,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const TQStringLis
             actionMenu = new TDEActionMenu( i18n( "Extract" ), "ark", actionCollection(), "ark_extract_menu"  );
 
             action = new TDEAction( i18n( "Extract Here" ), 0, this,
-                                    TQT_SLOT( slotExtractHere() ), actionCollection() );
+                                    TQ_SLOT( slotExtractHere() ), actionCollection() );
             actionMenu->insert( action );
             // stolen from arkwidget.cpp
             if ( itemCount == 1 )
@@ -145,22 +145,22 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const TQStringLis
                 TQString targetName = itemList.first()->name();
                 stripExtension( targetName );
                 action = new TDEAction( i18n( "Extract to %1" ).arg( targetName ), 0, this,
-                                        TQT_SLOT( slotExtractToSubfolders() ), actionCollection() );
+                                        TQ_SLOT( slotExtractToSubfolders() ), actionCollection() );
             }
             else
             {
                 action = new TDEAction( i18n( "Extract to Subfolders" ), 0, this,
-                                        TQT_SLOT( slotExtractToSubfolders() ), actionCollection() );
+                                        TQ_SLOT( slotExtractToSubfolders() ), actionCollection() );
             }
             actionMenu->insert( action );
             action = new TDEAction( i18n( "Extract To..." ), 0 , this,
-                                    TQT_SLOT( slotExtractTo() ), actionCollection() );
+                                    TQ_SLOT( slotExtractTo() ), actionCollection() );
             actionMenu->insert( action );
             addAction( actionMenu );
         }
         else
         {
-           action = new TDEAction( i18n( "Extract To..." ), "ark", 0,  this, TQT_SLOT( slotExtractTo() ), actionCollection(), "ark_extract_menu" );
+           action = new TDEAction( i18n( "Extract To..." ), "ark", 0,  this, TQ_SLOT( slotExtractTo() ), actionCollection(), "ark_extract_menu" );
            addAction( action );
         }
     }
@@ -174,8 +174,8 @@ ArkMenu::~ArkMenu()
 
 void ArkMenu::slotPrepareCompAsMenu()
 {
-    disconnect( m_compAsMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ),
-                this, TQT_SLOT( slotPrepareCompAsMenu() ) );
+    disconnect( m_compAsMenu->popupMenu(), TQ_SIGNAL( aboutToShow() ),
+                this, TQ_SLOT( slotPrepareCompAsMenu() ) );
 
     TDEAction * action;
     m_compAsMapper = new TQSignalMapper( this, "compAsMapper" );
@@ -196,13 +196,13 @@ void ArkMenu::slotPrepareCompAsMenu()
         if ( m_urlList.count() == 1 )
         {
             action = new TDEAction( m_name + (*eit), 0, m_compAsMapper,
-                    TQT_SLOT( map() ), actionCollection() );
+                    TQ_SLOT( map() ), actionCollection() );
         }
         else
         {
             ext = KMimeType::mimeType(*mit)->comment();
             action = new TDEAction( ext, 0, m_compAsMapper,
-                    TQT_SLOT( map() ), actionCollection() );
+                    TQ_SLOT( map() ), actionCollection() );
         }
 
         m_compAsMenu->insert( action );
@@ -219,13 +219,13 @@ void ArkMenu::slotPrepareCompAsMenu()
         m_extensionList += newExt;
     }
 
-    connect( m_compAsMapper, TQT_SIGNAL( mapped( int ) ), TQT_SLOT( slotCompressAs( int ) ) );
+    connect( m_compAsMapper, TQ_SIGNAL( mapped( int ) ), TQ_SLOT( slotCompressAs( int ) ) );
 }
 
 void ArkMenu::slotPrepareAddToMenu()
 {
-    disconnect( m_addToMenu->popupMenu(), TQT_SIGNAL( aboutToShow() ),
-                this, TQT_SLOT( slotPrepareAddToMenu() ) );
+    disconnect( m_addToMenu->popupMenu(), TQ_SIGNAL( aboutToShow() ),
+                this, TQ_SLOT( slotPrepareAddToMenu() ) );
 
 
     if ( m_extensionList.isEmpty() ) // is filled in slotPrepareCompAsMenu
@@ -246,7 +246,7 @@ void ArkMenu::slotPrepareAddToMenu()
             if ( (*uit).endsWith(*mit) )
             {
                 action = new TDEAction( *uit, 0, m_addToMapper,
-                                      TQT_SLOT( map() ), actionCollection() );
+                                      TQ_SLOT( map() ), actionCollection() );
                 m_addToMenu->insert( action );
                 m_addToMapper->setMapping( action, counter );
                 archive.setPath( *uit );
@@ -255,7 +255,7 @@ void ArkMenu::slotPrepareAddToMenu()
                 break;
             }
     }
-    connect( m_addToMapper, TQT_SIGNAL( mapped( int ) ), TQT_SLOT( slotAddTo( int ) ) );
+    connect( m_addToMapper, TQ_SIGNAL( mapped( int ) ), TQ_SLOT( slotAddTo( int ) ) );
 }
 
 void ArkMenu::compMimeTypes()
@@ -299,6 +299,13 @@ void ArkMenu::compMimeTypes()
         m_archiveMimeTypes << "application/x-lzma";
     }
 
+    bool havelzip = false;
+    if ( !TDEStandardDirs::findExe( "lzip" ).isNull() && m_conf->readBoolEntry( "UseLzip", false ) )
+    {
+        havelzip = true;
+        m_archiveMimeTypes << "application/x-lzip";
+    }
+
     if ( !TDEStandardDirs::findExe( "tar" ).isNull() && m_conf->readBoolEntry( "UseTar", true ) )
     {
         if ( havexz )
@@ -310,6 +317,8 @@ void ArkMenu::compMimeTypes()
         if ( havelzop )
             m_archiveMimeTypes << "application/x-tzo";
         if ( havelzma )
+            m_archiveMimeTypes << "application/x-tlzma";
+        if ( havelzip )
             m_archiveMimeTypes << "application/x-tlz";
         m_archiveMimeTypes << "application/x-tar";
     }
@@ -387,6 +396,13 @@ void ArkMenu::extMimeTypes()
         m_extractMimeTypes << "application/x-lzma";
     }
 
+    bool havelzip = false;
+    if ( !TDEStandardDirs::findExe( "lzip" ).isNull() )
+    {
+        havelzip = true;
+        m_extractMimeTypes << "application/x-lzip";
+    }
+
     if ( !TDEStandardDirs::findExe( "tar" ).isNull() )
     {
         if ( havexz )
@@ -398,6 +414,8 @@ void ArkMenu::extMimeTypes()
         if ( havelzop )
             m_extractMimeTypes << "application/x-tzo";
         if ( havelzma )
+            m_extractMimeTypes << "application/x-tlzma";
+        if ( havelzip )
             m_extractMimeTypes << "application/x-tlz";
         m_extractMimeTypes << "application/x-tar";
     }
