@@ -38,7 +38,7 @@ void Metabar::handlePreview(const KFileItemList &items)
 
 extern "C"
 {
-	KDE_EXPORT bool add_konqsidebar_metabar(TQString* fn, TQString* param, TQMap<TQString,TQString> *map)
+	TDE_EXPORT bool add_konqsidebar_metabar(TQString* fn, TQString* param, TQMap<TQString,TQString> *map)
 	{
 		Q_UNUSED(param);
 
@@ -54,7 +54,7 @@ extern "C"
 
 extern "C"
 {
-	KDE_EXPORT void* create_konqsidebar_metabar(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
+	TDE_EXPORT void* create_konqsidebar_metabar(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
 	{
 		return new Metabar(instance,par,widp,desktopname,name);
 	}
